"""
    Name: __init__.py
    Author: Charles Zhang <694556046@qq.com>
    Propose: __init__ for pygrading.
    Coding: UTF-8
"""

__version__ = "0.4.1"


def version():
    print(__version__)
